<?php

namespace EventPortal\Domain\Form\Factories;

use EventPortal\Domain\Component\Facades\Input;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Field\Models\Field;
use Illuminate\Support\Arr;

class SectionFactory
{
    public function display(Field $field): Section
    {
        $section = Section::make($field->label);

        $field->loadMissing('children');

        $section->children = $field
            ->children
            ->map(static function ($child) {
                return Input::display($child)->toArray();
            });

        return $section;
    }

    /**
     * @param array|Field $argument
     */
    public function make($argument): Section
    {
        if ($argument instanceof Field) {
            return $this->makeFromField($argument);
        }

        return $this->makeFromArray($argument);
    }

    public function makeFromArray(array $data): Section
    {
        $section = Section::make(Arr::get($data, 'label'));

        collect($data['children'])
            ->each(static function ($child) use ($section): void {
                $section->addChild(function () use ($child) {
                    return Input::fromArray($child);
                });
            });

        return $section;
    }

    public function makeFromField(Field $field): Section
    {
        $section = Section::make($field->label);

        $field->loadMissing('children');

        $section->children = $field
            ->children
            ->map(function ($child) {
                return Input::fromField($child)->toArray();
            });

        return $section;
    }
}
