<?php

namespace EventPortal\Domain\Util;

use EventPortal\Exceptions\NoDefaultConfig;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;

class DefaultConfig
{
    /** @var string */
    protected $model;

    public function __construct(string $modelClass)
    {
        $this->model = $this->setType($modelClass);
    }

    public static function for(string $modelClass): self
    {
        return new static($modelClass);
    }

    public function asCollection(): Collection
    {
        return collect($this->get());
    }

    public function get(string $type): array
    {
        $config = config("defaults.{$this->model}.{$type}");

        throw_if($config === null, NoDefaultConfig::class, 'Config type fields not found.');

        return $config;
    }

    private function setType(string $modelClass): string
    {
        return Str::of($modelClass)->afterLast('\\')->lower();
    }
}
