<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Event\Actions\DeleteTeam;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Inertia\Inertia;
use Inertia\Response;

class TeamController extends Controller
{
    public function index(): Response
    {
        $teams = Team::all();
        return Inertia::render('Team/Index', compact('teams'));
    }

    public function create(): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add('Create a team')
            ->get();

        return Inertia::render('Team/Create', [
            'breadcrumbs' => $breadcrumbs,
        ]);
    }

    public function store(Request $request): RedirectResponse
    {
        $team = Team::create($request->only([
            'slug',
            'name',
            'description',
        ]));

        return redirect()->route('admin.team.index');
    }

    public function edit(Team $team): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add($team->name, route('admin.team.show', $team->id))
            ->get();

        return Inertia::render('Team/Edit', [
            'team' => $team,
            'breadcrumbs' => $breadcrumbs,
        ]);
    }

    public function update(Team $team, Request $request): RedirectResponse
    {
        $team->update($request->only([
            'slug',
            'name',
            'description',
        ]));

        return redirect()->route('admin.team.index');
    }

    public function show(Team $team): Response
    {
        $breadcrumbs = Breadcrumb::make()
            ->add('Teams', route('admin.team.index'))
            ->add($team->name)
            ->get();

        return Inertia::render('Team/Show', [
            'team' => $team,
            'breadcrumbs' => $breadcrumbs,
        ]);
    }

    public function delete(Team $team, DeleteTeam $deleteTeam): RedirectResponse
    {
        $deleteTeam->execute($team);
        return redirect()->route('admin.team.index');
    }
}
